#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
NBE-E4210 Exercise 6 EEG RT measurement
Created on 2017-11-28
Last edited on 2019-11-26

@author: Marko Havu
"""
from psychopy import core, visual, event, logging, sound, parallel
import random, datetime, time
import pyo
 
## Setup section
# experiment specific
win = visual.Window([1920, 1080], units='height', winType='pyglet', fullscr=True)
width = float(win.size[0]) / win.size[1] # actual width in units of height
logging.console.setLevel(logging.WARNING) # default, only Errors and Warnings are shown on the console
parallel.setPortAddress(0x378)
pyo.Server(sr=44100, nchnls=2, duplex=0).setOutputDevice(46) # ASIO Fireface USB

# run  specific
fileName ='rt' + datetime.datetime.now().strftime("%Y%m%d%H%M%S")+".dat"
dataFile = open(fileName, 'w')
dataFile.write('#{}, {}\n'.format('stimulus', 'RT'))

# Create the design
MIN_MAX_ISI = (2.0, 7.0) # [min, max] interstimulus interval

box = visual.Rect(win, width=0.2, height=0.2, pos=(0, 0),
                  fillColor='green', lineColor='green')
beep = sound.Sound(value='C') 
welcome = 'Next stimulus type is %s.\nPress spacebar when ready.'

def visualStim():
    box.draw()
    win.flip()
    parallel.setPin(2,1)
    timeBefore = time.time()
    presses = event.waitKeys()
    parallel.setData(0)
    timeAfter = time.time()
    win.flip()
    return (presses, timeAfter - timeBefore)

def auralStim():
    parallel.setPin(3,1)
    beep.play()
    timeBefore = time.time()
    presses = event.waitKeys()
    parallel.setData(0)
    timeAfter = time.time()
    return (presses, timeAfter - timeBefore - 0.200)


## Experiment section
# 15 sets of both types of stimuli in random order
stimuli = 15 * [('aural', auralStim), ('visual', visualStim)]
random.shuffle(stimuli)
for stimulus in stimuli:
    instruction = visual.TextStim(win, text=welcome % stimulus[0], height=0.02)
    instruction.draw(win)
    win.flip()
    event.waitKeys()
    win.flip()
    # Group 1 had 5 stimuli in a set, group 2 had 6
    for i in range(6):
        isi = random.uniform(MIN_MAX_ISI[0], MIN_MAX_ISI[1])
        core.wait(isi)
        presses, rt = stimulus[1]()
        if presses[0] == 'escape':
            core.quit()
        dataFile.write('{}, {}\n'.format(stimulus[0], rt))
instruction = visual.TextStim(win, text='That was the last stimulus.\nThank you!', height=0.02)
instruction.draw(win)
win.flip()
event.waitKeys()

## Cleanup section
win.close()
core.quit()
